2.2.1 (Sep 12, 2016)
~~~~~~~~~~~~~~~~~~~~

- Bugfix logging configuration

2.2.0 (Sep 12, 2016)
~~~~~~~~~~~~~~~~~~~~

- Support Tornado adapter
- Improve logging configuration

2.1.3 (Aug 10, 2016)
~~~~~~~~~~~~~~~~~~~~

- Simpler configuration of the id part of requests

2.1.2 (Aug 8, 2016)
~~~~~~~~~~~~~~~~~~~

- Fixed a bug when logging http requests.
- Create default log handlers if user hasn't configured any.

2.1.1 (Jul 22, 2016)
~~~~~~~~~~~~~~~~~~~~

- More flexible configuration of requests in `HTTPServer
  <https://jsonrpcclient.readthedocs.io/en/latest/http.html#configuration>`_.
